package cn.com.infosec.asn1.pkcs;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import java.math.BigInteger;
import java.util.Enumeration;

public class PBKDF2Params extends ASN1Encodable {
   ASN1OctetString octStr;
   DERInteger iterationCount;
   DERInteger keyLength;

   public static PBKDF2Params getInstance(Object obj) {
      if (obj instanceof PBKDF2Params) {
         return (PBKDF2Params)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new PBKDF2Params((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public PBKDF2Params(byte[] salt, int iterationCount) {
      PBKDF2Params var10000 = this;
      PBKDF2Params var10001 = this;
      super();
      DEROctetString var3;
      var3 = new DEROctetString.<init>(salt);
      var10001.octStr = var3;
      DERInteger var4;
      var4 = new DERInteger.<init>(iterationCount);
      var10000.iterationCount = var4;
   }

   public PBKDF2Params(ASN1Sequence seq) {
      Enumeration seq1;
      this.octStr = (ASN1OctetString)(seq1 = seq.getObjects()).nextElement();
      this.iterationCount = (DERInteger)seq1.nextElement();
      if (seq1.hasMoreElements()) {
         this.keyLength = (DERInteger)seq1.nextElement();
      } else {
         this.keyLength = null;
      }

   }

   public byte[] getSalt() {
      return this.octStr.getOctets();
   }

   public BigInteger getIterationCount() {
      return this.iterationCount.getValue();
   }

   public BigInteger getKeyLength() {
      DERInteger var1;
      return (var1 = this.keyLength) != null ? var1.getValue() : null;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.octStr);
      var10001.add(this.iterationCount);
      DERInteger var2;
      if ((var2 = this.keyLength) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
